@@ -48,8 +48,8 @@ namespace XMPP
 		inline FTThumbnail() : width(0), height(0) {}
 		// data - for outgoing it's actual image data. for incoming - cid
 		inline FTThumbnail(const QByteArray &data,
-						   const QString &mimeType = QString::null,
-						   quint32 width = 0, quint32 height = 0) :
+				   const QString &mimeType = QString(),
+				   quint32 width = 0, quint32 height = 0) :
 			data(data), mimeType(mimeType),
 			width(width), height(height) { }
 		inline bool isNull() const { return data.isNull(); }
@@ -170,8 +170,8 @@ namespace XMPP
 		qlonglong rangeLength() const;
 		QString streamType() const;
 
-		void onGo();
-		bool take(const QDomElement &);
+		void onGo() override;
+		bool take(const QDomElement &) override;
 
 	private:
 		class Private;
@@ -200,7 +200,7 @@ namespace XMPP
 		void respondError(const Jid &to, const QString &id,
 						  Stanza::Error::ErrorCond cond, const QString &str);
 
-		bool take(const QDomElement &);
+		bool take(const QDomElement &) override;
 
 	signals:
 		void incoming(const FTRequest &req);
