@@ -34,14 +34,13 @@ public:
 	
 	~CloseConnectionTask();
 	
-	virtual bool take(Transfer* transfer);
+	bool take(Transfer* transfer) Q_DECL_OVERRIDE;
 
 protected:
-	virtual bool forMe(const Transfer* transfer) const;
-	virtual void onGo();
+	bool forMe(const Transfer* transfer) const Q_DECL_OVERRIDE;
+	void onGo() Q_DECL_OVERRIDE;
 
 };
 
 #endif
 
-//kate: indent-mode csands; space-indent off; tab-width 4; replace-tabs off;
